@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.31'; # VERSION
 
 our %SPEC;
 
@@ -55,15 +55,13 @@ sub pick {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::pick - Pick one or more random items
 
 =head1 VERSION
 
-version 1.30
+version 1.31
 
 =head1 SYNOPSIS
 
@@ -90,34 +88,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 pick() -> [status, msg, result, meta]
 
-=head2 pick(%args) -> [status, msg, result, meta]
-
-Pick one or more random items.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<items> => I<int> (default: 1)
-
-Number of items to pick.
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=back
+No arguments.
 
 Return value:
 
