@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.31'; # VERSION
 
 use Data::Unixish::Util qw(%common_args);
 
@@ -52,15 +52,13 @@ sub tail {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::tail - Output the last items of data
 
 =head1 VERSION
 
-version 1.30
+version 1.31
 
 =head1 SYNOPSIS
 
@@ -91,34 +89,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 tail() -> [status, msg, result, meta]
 
-=head2 tail(%args) -> [status, msg, result, meta]
-
-Output the last items of data.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<items> => I<int> (default: 10)
-
-Number of items to output.
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=back
+No arguments.
 
 Return value:
 
