@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.31'; # VERSION
 
 use Data::Unixish::Util qw(%common_args);
 
@@ -57,15 +57,13 @@ sub trim {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::trim - Strip whitespace at the beginning and end of each line of text
 
 =head1 VERSION
 
-version 1.30
+version 1.31
 
 =head1 SYNOPSIS
 
@@ -92,34 +90,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 trim() -> [status, msg, result, meta]
 
-=head2 trim(%args) -> [status, msg, result, meta]
-
-Strip whitespace at the beginning and end of each line of text.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=item * B<strip_newline> => I<bool> (default: 0)
-
-Whether to strip newlines at the beginning and end of text.
-
-=back
+No arguments.
 
 Return value:
 
