@@ -11,7 +11,7 @@ use Data::Unixish::Util qw(%common_args);
 use Text::ANSI::Util qw(ta_trunc ta_mbtrunc);
 use Text::WideChar::Util qw(mbtrunc);
 
-our $VERSION = '1.30'; # VERSION
+our $VERSION = '1.31'; # VERSION
 
 our %SPEC;
 
@@ -81,15 +81,13 @@ sub trunc {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-version 1.30
+version 1.31
 
 =head1 SYNOPSIS
 
@@ -116,46 +114,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 trunc() -> [status, msg, result, meta]
 
-=head2 trunc(%args) -> [status, msg, result, meta]
-
-Truncate string to a certain column width.
-
-This function can handle text containing wide characters and ANSI escape codes.
-
-Note: to truncate by character instead of column width (note that wide
-characters like Chinese can have width of more than 1 column in terminal), you
-can turn of C<mb> option even when your text contains wide characters.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<ansi> => I<bool> (default: 0)
-
-Whether to handle ANSI escape codes.
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<mb> => I<bool> (default: 0)
-
-Whether to handle wide characters.
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=item * B<width>* => I<int>
-
-=back
+No arguments.
 
 Return value:
 
